SystemOrganization addCategory: #NumberPrinterTests!

TestCase subclass: #FloatPrinterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NumberPrinterTests'!

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 6/2/2012 21:13'!
testFixedFormat
	| printer |
	printer := FloatPrinter fixed.
	self assert: (printer print: 0.0) equals: '0'.
	self assert: (printer print: 1000000.0) equals: '1000000'.
	self assert: (printer print: 1000.0) equals: '1000'.
	self assert: (printer print: 10.0) equals: '10'.
	self assert: (printer print: -1.0) equals: '-1'.
	self assert: (printer print: 0.1) equals: '0.1'.
	self assert: (printer print: 0.0001) equals: '0.0001'.
	self assert: (printer print: 0.000001) equals: '0.000001'.
	printer alwaysPrintFractionSeparator: true.
	self assert: (printer print: 0.0) equals: '0.'.
	self assert: (printer print: -300.0) equals: '-300.'.
	self assert: (printer print: 4.0) equals: '4.'.
	self assert: (printer print: 0.06) equals: '0.06'.
	printer alwaysPrintFractionPart: true.
	self assert: (printer print: 0.0) equals: '0.0'.
	self assert: (printer print: 70.0) equals: '70.0'.
	self assert: (printer print: 8.0) equals: '8.0'.
	self assert: (printer print: 0.9) equals: '0.9'.
	printer positiveSignChar: $+.
	self assert: (printer print: 0.0) equals: '+0.0'.
	self assert: (printer print: -300.1) equals: '-300.1'.
	self assert: (printer print: 0.0579) equals: '+0.0579'.
	printer positiveSignChar: $ .
	self assert: (printer print: 2.3) equals: ' 2.3'.
	printer fractionSeparator: $,.
	self assert: (printer print: 0.0) equals: ' 0,0'.
	self assert: (printer print: -5.8) equals: '-5,8'.
	self assert: (printer print: 0.042) equals: ' 0,042'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 6/3/2012 14:07'!
testFixedFormatFixedWidth
	| printer |
	printer := FloatPrinter fixed.
	printer totalWidth: 10.
	self assert: (printer print: 1.234) size equals: 10.
	self assert: (printer print: 1.234) equals: '     1.234'.
	self assert: (printer print: -1.234) equals: '    -1.234'.
	self assert: (printer print: Float pi) size > 10.
	printer padWithZeros: true.
	self assert: (printer print: 1.234) equals: '000001.234'.
	self assert: (printer print: -1.234) equals: '-00001.234'.
	printer positiveSignChar: $ .
	self assert: (printer print: 1.234) equals: ' 00001.234'.
	printer digitCount: 2.
	self assert: (printer print: 1.234) equals: ' 000001.23'.
	printer padWithZeros: false.
	printer positiveSignChar: $+.
	self assert: (printer print: 1.234) equals: '     +1.23'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 6/2/2012 22:24'!
testFixedFormatWithDigitCount
	| printer |
	printer := FloatPrinter fixed.
	printer digitCount: 0.
	self assert: (printer print: Float pi) equals: '3'.
	printer digitCount: 1.
	self assert: (printer print: Float pi) equals: '3.1'.
	printer digitCount: 2.
	self assert: (printer print: Float pi) equals: '3.14'.
	self assert: (printer print: 9.99499) equals: '9.99'.
	self assert: (printer print: 9.9499) equals: '9.95'.
	self assert: (printer print: 0.99499) equals: '0.99'.
	self assert: (printer print: 0.099499) equals: '0.1'.
	self assert: (printer print: 0.099501) equals: '0.1'.
	self assert: (printer print: 0.99501) equals: '1'.
	self assert: (printer print: 9.9501) equals: '9.95'.
	self assert: (printer print: 9.99501) equals: '10'.
	printer digitCount: 3.
	self assert: (printer print: Float pi) equals: '3.142'.
	self assert: (printer print: 0.099499) equals: '0.099'.
	self assert: (printer print: 0.099501) equals: '0.1'.
	printer digitCount: 4.
	self assert: (printer print: Float pi) equals: '3.1416'.
	self assert: (printer print: 0.1200499) equals: '0.12'.
	self assert: (printer print: 0.1200501) equals: '0.1201'.
	
	printer := FloatPrinter fixed.
	printer showTrailingZeros: true.
	printer digitCount: 2.
	self assert: (printer print: 0.99501) equals: '1.00'.
	self assert: (printer print: 0.101) equals: '0.10'.
! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 6/2/2012 20:47'!
testFreeFormat
	| printer |
	printer := FloatPrinter freeFormat.
	self assert: (printer print: 0.0) equals: '0'.
	self assert: (printer print: 10000000.0) equals: '1e7'.
	self assert: (printer print: 1000000.0) equals: '1e6'.
	self assert: (printer print: 100000.0) equals: '100000'.
	self assert: (printer print: 10000.0) equals: '10000'.
	self assert: (printer print: 1000.0) equals: '1000'.
	self assert: (printer print: 100.0) equals: '100'.
	self assert: (printer print: 10.0) equals: '10'.
	self assert: (printer print: -1.0) equals: '-1'.
	self assert: (printer print: 0.1) equals: '0.1'.
	self assert: (printer print: 0.01) equals: '0.01'.
	self assert: (printer print: 0.001) equals: '0.001'.
	self assert: (printer print: 0.0001) equals: '0.0001'.
	self assert: (printer print: 0.00001) equals: '1e-5'.
	self assert: (printer print: 0.000001) equals: '1e-6'.
	printer alwaysPrintFractionSeparator: true.
	self assert: (printer print: 0.0) equals: '0.'.
	self assert: (printer print: 20000000.0) equals: '2.e7'.
	self assert: (printer print: 300.0) equals: '300.'.
	self assert: (printer print: 40.0) equals: '40.'.
	self assert: (printer print: 5.0) equals: '5.'.
	self assert: (printer print: -0.6) equals: '-0.6'.
	self assert: (printer print: 0.07) equals: '0.07'.
	self assert: (printer print: 0.000008) equals: '8.e-6'.
	printer alwaysPrintFractionPart: true.
	self assert: (printer print: 0.0) equals: '0.0'.
	self assert: (printer print: 10000000.0) equals: '1.0e7'.
	self assert: (printer print: 100.0) equals: '100.0'.
	self assert: (printer print: -10.0) equals: '-10.0'.
	self assert: (printer print: 1.0) equals: '1.0'.
	self assert: (printer print: 0.1) equals: '0.1'.
	self assert: (printer print: 0.01) equals: '0.01'.
	self assert: (printer print: 0.000001) equals: '1.0e-6'.
	printer positiveSignChar: $+.
	self assert: (printer print: 0.0) equals: '+0.0'.
	self assert: (printer print: 10200000.0) equals: '+1.02e+7'.
	self assert: (printer print: 100.03) equals: '+100.03'.
	self assert: (printer print: 0.014) equals: '+0.014'.
	self assert: (printer print: -0.00000105) equals: '-1.05e-6'.
	printer positiveSignChar: $ .
	self assert: (printer print: 10030000.0) equals: ' 1.003e+7'.
	printer exponentChar: $d.
	self assert: (printer print: 10030000.0) equals: ' 1.003d+7'.
	printer exponentDigitCount: 2.
	self assert: (printer print: 10030000.0) equals: ' 1.003d+07'.
	self assert: (printer print: -0.00000105) equals: '-1.05d-06'.
	printer fractionSeparator: $,.
	self assert: (printer print: 0.0) equals: ' 0,0'.
	self assert: (printer print: -0.00000105) equals: '-1,05d-06'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 6/3/2012 14:37'!
testFreeFormatFixedWidth
	| printer |
	printer := FloatPrinter freeFormat.
	printer totalWidth: 7.
	self assert: (printer print: 100.0) size equals: 7.
	self assert: (printer print: 100.0) equals: '    100'.
	self assert: (printer print: 1000.0) equals: '    1e3'. "Shortest notation is used"
	self assert: (printer print: -1001.0) equals: '  -1001'. "Shortest notation is used"
	printer digitCount: 2.
	self assert: (printer print: -10012.0) equals: '   -1e4'. "Shortest notation is used"
	printer showTrailingZeros: true.
	self assert: (printer print: -10012.0) equals: ' -10000'. "Shortest notation is used"! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 6/2/2012 23:57'!
testFreeFormatWithDigitCount
	| printer |
	printer := FloatPrinter freeFormat.
	printer digitCount: 1.
	self assert: (printer print: 0.0) equals: '0'.
	self assert: (printer print: 100.0) equals: '1e2'.
	self assert: (printer print: 10.0) equals: '1e1'.
	self assert: (printer print: -1.0) equals: '-1'.
	self assert: (printer print: 0.1) equals: '1e-1'.
	self assert: (printer print: 9.49) equals: '9'.
	self assert: (printer print: 0.949) equals: '9e-1'.
	self assert: (printer print: 0.951) equals: '1'.
	self assert: (printer print: 9.51) equals: '1e1'.
	self assert: (printer print: 0.0951) equals: '1e-1'.
	
	printer digitCount: 2.
	self assert: (printer print: 100.0) equals: '1e2'.
	self assert: (printer print: 10.0) equals: '10'.
	self assert: (printer print: -1.0) equals: '-1'.
	self assert: (printer print: 0.1) equals: '1e-1'.
	self assert: (printer print: 9.949) equals: '9.9'.
	self assert: (printer print: 0.9949) equals: '9.9e-1'.
	self assert: (printer print: 0.9951) equals: '1'.
	self assert: (printer print: 9.951) equals: '10'.

	printer showTrailingZeros: true.
	self assert: (printer print: 100.0) equals: '1.0e2'.
	self assert: (printer print: 10.0) equals: '10'.
	self assert: (printer print: -1.0) equals: '-1.0'.
	self assert: (printer print: 0.1) equals: '1.0e-1'.
	self assert: (printer print: 99.49) equals: '99'.
	self assert: (printer print: 9.949) equals: '9.9'.
	self assert: (printer print: 0.9949) equals: '9.9e-1'.
	self assert: (printer print: 0.9951) equals: '1.0'.
	self assert: (printer print: 9.951) equals: '10'.
	self assert: (printer print: 99.51) equals: '1.0e2'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 6/2/2012 21:02'!
testScientificFormat
	| printer |
	printer := FloatPrinter scientific.
	self assert: (printer print: 0.0) equals: '0e0'.
	self assert: (printer print: 1000.0) equals: '1e3'.
	self assert: (printer print: 100.0) equals: '1e2'.
	self assert: (printer print: 10.0) equals: '1e1'.
	self assert: (printer print: -1.0) equals: '-1e0'.
	self assert: (printer print: 0.1) equals: '1e-1'.
	self assert: (printer print: 0.01) equals: '1e-2'.
	self assert: (printer print: 0.001) equals: '1e-3'.
	printer alwaysPrintFractionSeparator: true.
	self assert: (printer print: 0.0) equals: '0.e0'.
	self assert: (printer print: -300.0) equals: '-3.e2'.
	self assert: (printer print: 4.0) equals: '4.e0'.
	self assert: (printer print: 0.06) equals: '6.e-2'.
	printer alwaysPrintFractionPart: true.
	self assert: (printer print: 0.0) equals: '0.0e0'.
	self assert: (printer print: 70.0) equals: '7.0e1'.
	self assert: (printer print: -0.8) equals: '-8.0e-1'.
	printer positiveSignChar: $+.
	self assert: (printer print: 0.0) equals: '+0.0e+0'.
	self assert: (printer print: -300.1) equals: '-3.001e+2'.
	self assert: (printer print: 0.0579) equals: '+5.79e-2'.
	printer positiveSignChar: $ .
	self assert: (printer print: 2.3) equals: ' 2.3e+0'.
	printer exponentChar: $d.
	self assert: (printer print: 2.3) equals: ' 2.3d+0'.
	printer exponentDigitCount: 2.
	self assert: (printer print: -310.0) equals: '-3.1d+02'.
	self assert: (printer print: 4.0) equals: ' 4.0d+00'.
	self assert: (printer print: 0.06) equals: ' 6.0d-02'.
	self assert: (printer print: 1.0e100) equals: ' 1.0d+100'.
	printer fractionSeparator: $,.
	self assert: (printer print: 0.0) equals: ' 0,0d+00'.
	self assert: (printer print: -5.8) equals: '-5,8d+00'.
	self assert: (printer print: 0.042) equals: ' 4,2d-02'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 6/3/2012 14:15'!
testScientificFormatFixedWidth
	| printer |
	printer := FloatPrinter scientific.
	printer totalWidth: 8.
	self assert: (printer print: 0.1) equals: '    1e-1'.
	self assert: (printer print: -10.1) equals: ' -1.01e1'.
	printer padWithZeros: true.
	self assert: (printer print: -10.1) equals: '-01.01e1'.
	self assert: (printer print: 3.14) equals: '003.14e0'.
	printer positiveSignChar: $+.
	printer totalWidth: 10.
	self assert: (printer print: 3.14) equals: '+003.14e+0'.
	self assert: (printer print: Float pi) size > 10.
	self assert: (Number readFromString: (printer print: Float pi)) equals: Float pi.
	printer digitCount: 2.
	printer padWithZeros: false.
	self assert: (printer print: Float pi) equals: '  +3.14e+0'.
	! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 6/2/2012 23:06'!
testScientificFormatWithDigitCount
	| printer |
	printer := FloatPrinter scientific.
	printer digitCount: 0.
	self assert: (printer print: 0.0) equals: '0e0'.
	self assert: (printer print: 1000.0) equals: '1e3'.
	self assert: (printer print: 1200.0) equals: '1e3'.
	self assert: (printer print: 0.01) equals: '1e-2'.
	self assert: (printer print: 1.7) equals: '2e0'.
	self assert: (printer print: 0.17) equals: '2e-1'.
	self assert: (printer print: 0.017) equals: '2e-2'.
	self assert: (printer print: 9.9) equals: '1e1'.
	self assert: (printer print: 0.99) equals: '1e0'.
	printer digitCount: 1.
	self assert: (printer print: 1.7) equals: '1.7e0'.
	self assert: (printer print: 0.17) equals: '1.7e-1'.
	self assert: (printer print: 0.017) equals: '1.7e-2'.
	self assert: (printer print: 100.0) equals: '1e2'.
	self assert: (printer print: 130.0) equals: '1.3e2'.
	self assert: (printer print: 9.99) equals: '1e1'.
	self assert: (printer print: 0.99499) equals: '9.9e-1'.
	self assert: (printer print: 0.996) equals: '1e0'.
	
	printer showTrailingZeros: true.
	printer digitCount: 2.
	self assert: (printer print: 9.99499) equals: '9.99e0'.
	self assert: (printer print: 0.999499) equals: '9.99e-1'.
	self assert: (printer print: 0.0999499) equals: '9.99e-2'.
	self assert: (printer print: 0.0999501) equals: '1.00e-1'.
	self assert: (printer print: 0.999501) equals: '1.00e0'.
	self assert: (printer print: 9.99501) equals: '1.00e1'.
	self assert: (printer print: -314.159) equals: '-3.14e2'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 4/7/2016 21:27'!
testThousandFormat
	| printer |
	printer := FloatPrinter thousand.
	self assert: (printer print: 0.0) equals: '0'.
	self assert: (printer print: 10.0) equals: '10'.
	self assert: (printer print: 100.0) equals: '100'.
	self assert: (printer print: 1000.0) equals: '1e3'.
	self assert: (printer print: 10000.0) equals: '10e3'.
	self assert: (printer print: -1.0) equals: '-1'.
	self assert: (printer print: 0.1) equals: '100e-3'.
	self assert: (printer print: 0.01) equals: '10e-3'.
	self assert: (printer print: 0.001) equals: '1e-3'.
	printer alwaysPrintFractionSeparator: true.
	self assert: (printer print: 0.0) equals: '0.'.
	self assert: (printer print: -3000.0) equals: '-3.e3'.
	self assert: (printer print: 4.0) equals: '4.'.
	self assert: (printer print: 0.06) equals: '60.e-3'.
	printer alwaysPrintFractionPart: true.
	self assert: (printer print: 0.0) equals: '0.0'.
	self assert: (printer print: 70.0) equals: '70.0'.
	self assert: (printer print: -0.8) equals: '-800.0e-3'.
	printer positiveSignChar: $+.
	self assert: (printer print: 0.0) equals: '+0.0'.
	self assert: (printer print: -3000.1) equals: '-3.0001e+3'.
	self assert: (printer print: 0.0579) equals: '+57.9e-3'.
	printer positiveSignChar: $ .
	self assert: (printer print: 2.3) equals: ' 2.3'.
	printer exponentChar: $d.
	self assert: (printer print: 2300) equals: ' 2.3d+3'.
	printer exponentDigitCount: 2.
	self assert: (printer print: -3100.0) equals: '-3.1d+03'.
	self assert: (printer print: 4.0) equals: ' 4.0'.
	self assert: (printer print: 0.06) equals: ' 60.0d-03'.
	self assert: (printer print: 1.0e110) equals: ' 100.0d+108'.
	printer fractionSeparator: $,.
	self assert: (printer print: 0.0) equals: ' 0,0'.
	self assert: (printer print: -5.8) equals: '-5,8'.
	self assert: (printer print: 0.0042) equals: ' 4,2d-03'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 4/7/2016 23:10'!
testThousandFormatFixedWidth
	| printer |
	printer := FloatPrinter thousand.
	printer totalWidth: 8.
	self assert: (printer print: 0.1) equals: '  100e-3'.
	self assert: (printer print: -10.1) equals: '   -10.1'.
	printer padWithZeros: true.
	self assert: (printer print: -10.1) equals: '  -010.1'.
	self assert: (printer print: 3.14) equals: '  003.14'.
	printer positiveSignChar: $+.
	printer totalWidth: 10.
	self assert: (printer print: 3.14) equals: '   +003.14'.
	self assert: (printer print: Float pi) size > 10.
	self assert: (Number readFromString: (printer print: Float pi)) equals: Float pi.
	printer digitCount: -2.
	printer padWithZeros: false.
	self assert: (printer print: Float pi) equals: '     +3.14'.
	! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 4/8/2016 00:20'!
testThousandFormatWithDigitCount
	| printer |
	printer := FloatPrinter thousand.
	printer digitCount: 1.
	self assert: (printer print: 0.0) equals: '0'.
	self assert: (printer print: 10000.0) equals: '10e3'.
	self assert: (printer print: 1200.0) equals: '1e3'.
	self assert: (printer print: 0.01) equals: '10e-3'.
	self assert: (printer print: 1.7) equals: '2'.
	self assert: (printer print: 0.17) equals: '200e-3'.
	self assert: (printer print: 0.017) equals: '20e-3'.
	self assert: (printer print: 9.9) equals: '10'.
	self assert: (printer print: 0.99) equals: '1'.
	printer digitCount: 5.
	self assert: (printer print: 100.099) equals: '100.1'.
	self assert: (printer print: 12345.67) equals: '12.346e3'.
	self assert: (printer print: 0.00999499) equals: '9.995e-3'.
	self assert: (printer print: 0.09999499) equals: '99.995e-3'.
	self assert: (printer print: 0.99999499) equals: '999.99e-3'.
	self assert: (printer print: 0.99999501) equals: '1'.
	printer digitCount: -1.
	self assert: (printer print: 1.7) equals: '1.7'.
	self assert: (printer print: 0.17) equals: '170e-3'.
	self assert: (printer print: 0.017) equals: '17e-3'.
	self assert: (printer print: 100.0) equals: '100'.
	self assert: (printer print: 130.0) equals: '130'.
	self assert: (printer print: 9.99) equals: '10'.
	self assert: (printer print: 0.999499) equals: '999.5e-3'.
	self assert: (printer print: 0.9996) equals: '999.6e-3'.
	
	printer showTrailingZeros: true.
	printer digitCount: -2.
	self assert: (printer print: 9.99499) equals: '9.99'.
	self assert: (printer print: 0.999499) equals: '999.50e-3'.
	self assert: (printer print: 0.0999499) equals: '99.95e-3'.
	self assert: (printer print: 0.00999499) equals: '9.99e-3'.
	self assert: (printer print: 0.00999501) equals: '10.00e-3'.
	self assert: (printer print: 0.0999501) equals: '99.95e-3'.
	self assert: (printer print: 0.999501) equals: '999.50e-3'.
	self assert: (printer print: 9.99501) equals: '10.00'.
	self assert: (printer print: -314.159) equals: '-314.16'.! !
